@@ -1,9 +1,12 @@
-# Copyright 2019 the authors.
+# Copyright 2020 the authors.
 # This file is part of Hy, which is free software licensed under the Expat
 # license. See the LICENSE.
 
 from __future__ import print_function
 
+import colorama
+colorama.init()
+
 import argparse
 import code
 import ast
@@ -19,6 +22,7 @@ import time
 import linecache
 import hashlib
 import codeop
+import builtins
 
 import astor.code_gen
 
@@ -35,7 +39,6 @@ from hy.importer import runhy
 from hy.completer import completion, Completer
 from hy.macros import macro, require
 from hy.models import HyExpression, HyString, HySymbol
-from hy._compat import builtins, PY3, FileNotFoundError
 
 
 sys.last_type = None
@@ -59,9 +62,19 @@ class HyQuitter(object):
             pass
         raise SystemExit(code)
 
+class HyHelper(object):
+    def __repr__(self):
+        return ("Use (help) for interactive help, or (help object) for help "
+                "about object.")
+
+    def __call__(self, *args, **kwds):
+        import pydoc
+        return pydoc.help(*args, **kwds)
+
 
 builtins.quit = HyQuitter('quit')
 builtins.exit = HyQuitter('exit')
+builtins.help = HyHelper()
 
 @contextmanager
 def extend_linecache(add_cmdline_cache):
@@ -256,7 +269,7 @@ class HyREPL(code.InteractiveConsole, object):
                 module, f = '.'.join(parts[:-1]), parts[-1]
                 self.output_fn = getattr(importlib.import_module(module), f)
             else:
-                self.output_fn = __builtins__[mangle(output_fn)]
+                self.output_fn = getattr(builtins, mangle(output_fn))
 
         # Pre-mangle symbols for repl recent results: *1, *2, *3
         self._repl_results_symbols = [mangle("*{}".format(i + 1)) for i in range(3)]
@@ -661,7 +674,7 @@ def hy2py_main():
     if options.with_source:
         # need special printing on Windows in case the
         # codepage doesn't support utf-8 characters
-        if PY3 and platform.system() == "Windows":
+        if platform.system() == "Windows":
             for h in hst:
                 try:
                     print(h)
@@ -676,7 +689,7 @@ def hy2py_main():
         _ast = hy_compile(hst, '__main__', filename=filename, source=source)
 
     if options.with_ast:
-        if PY3 and platform.system() == "Windows":
+        if platform.system() == "Windows":
             _print_for_windows(astor.dump_tree(_ast))
         else:
             print(astor.dump_tree(_ast))
@@ -684,7 +697,7 @@ def hy2py_main():
         print()
 
     if not options.without_python:
-        if PY3 and platform.system() == "Windows":
+        if platform.system() == "Windows":
             _print_for_windows(astor.code_gen.to_source(_ast))
         else:
             print(astor.code_gen.to_source(_ast))
